require(cmsaf)
require(rgdal)

clim = 'GFDL-ESM2G'
#------------------Precip------------------------
#This will merge all files in a directory by time
box_mergetime(var = 'pr', path = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85'), pattern = '', outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_day_', clim, '_rcp85_20700101-20991231.nc'), lon1=0, lon2=360, lat1=-90, lat2=90)
selyear(var = 'pr', year = c(2070:2099), infile = 'r:/climate/cmip5/canesm2/pr/rcp85/pr_day_CanESM2_rcp85_20060101-21001231.nc', outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_day_', clim, '_rcp85_20700101-20991231.nc'))
#Convert precip from flux to mm
cmsaf.mulc(var = 'pr', const = (24*3600), infile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_day_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_day_mm_', clim, '_rcp85_20700101-20991231.nc'))

#Calculate monthly sums across all years
monsum(var = 'pr', infile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_day_mm_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_monsum_', clim, '_rcp85_20700101-20991231.nc'))

#Calculate monthly means of precip
ymonmean(var = 'pr', infile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_monsum_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/pr/rcp85/pr_monmean_', clim, '_rcp85_20700101-20991231.nc'))

#------------------Temperature-------------------
#------------------tasmin------------------------
#This will merge all files in a directory by time
box_mergetime(var = 'tasmin', path = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85'), pattern = '', outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85/tasmin_day_', clim, '_rcp85_20700101-20991231.nc'), lon1=0, lon2=360, lat1=-90, lat2=90)

cmsaf.subc(var = 'tasmin', const = 273.15, infile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85/tasmin_day_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85/tasmin_day_c_', clim, '_rcp85_20700101-20991231.nc'))

#Calculate monthly means across all years
ymonmean(var = 'tasmin', infile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85/tasmin_day_c_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmin/rcp85/tasmin_monmean_', clim, '_rcp85_20700101-20991231.nc'))

#------------------tasmax------------------------
#This will merge all files in a directory by time
box_mergetime(var = 'tasmax', path = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85'), pattern = '', outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85/tasmax_day_', clim, '_rcp85_20700101-20991231.nc'), lon1=0, lon2=360, lat1=-90, lat2=90)

cmsaf.subc(var = 'tasmax', const = 273.15, infile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85/tasmax_day_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85/tasmax_day_c_', clim, '_rcp85_20700101-20991231.nc'))

#Calculate monthly means across all years
ymonmean(var = 'tasmax', infile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85/tasmax_day_c_', clim, '_rcp85_20700101-20991231.nc'), outfile = paste0('R:/CLIMATE/CMIP5/', clim, '/tasmax/rcp85/tasmax_monmean_', clim, '_rcp85_20700101-20991231.nc'))


#------------------Plot PHZ maps-----------------
stateLyr = readOGR('Q:/UnitedStates', 'cb_2016_us_state_500k_conterminus')
#source https://www.census.gov/geo/maps-data/data/cbf/cbf_state.html
minRas = raster('./PHZ/meanmintemp_CURRENT_19810101-20101231.nc')

#Check to see if raster is in 0-360 longitude and convert to -180 to 180 if true
if (extent(minRas)[1] > 180){
  minRas = rotate(minRas)
}

stateLyr = spTransform(stateLyr, crs(minRas))

#Color palette and legend labels
colPal = c('#C7C9E5','#B7BCDE','#A1A7D2','#E2A7CA','#CB8DBD','#C07EB4','#8B69AC','#566FB3','#6396CD','#15BDCB','#00AB52','#43B759','#8DC872','#BED979','#F2D888','#F6CA60','#E6B556','#F9AD77','#EF973E','#F2792E','#F05D2F','#F48467','#F05E56','#DC1A38','#B13329','#871315')
zones = paste(rep(1:13, each = 2), c('a', 'b'), sep='')

#Reclassify minimum temperature to zone
recl = data.frame(low = seq(from = -60, to = 65, by = 5), high = seq(from = -55, to = 70, by = 5), zone = 1:26)
minRas = reclassify(minRas, recl)

#Plot and save as PNG
png(filename = './PHZ/CURRENT_PHZ.png', width = 8, height=6, units = 'in', res=300)
plot(minRas, legend=F, col=colPal[cellStats(minRas, min):cellStats(minRas, max)], las=1, main='Current Plant Hardiness Zones')
plot(stateLyr, add=T)
legend(x='topright', inset=c(-0.096,0), xpd = T, legend=zones, fill=colPal, cex=0.77)
dev.off()
